@@ -49,12 +49,12 @@ def parse_arguments(argsv: str = None) -> argparse.Namespace:
         dest="file",
         action="store",
         nargs="?",
-        help="For `data_submission` sub-command: string, path to html form. "
-        "For `process` sub-command: string, override path to `.csv` file in config, "
-        "listing newly delivered sequencing data from the genome center core. "
-        "A special case for `process` sub-command: pass `-`, and follow "
-        "the prompt on screen. For more details and examples follow the documentation "
-        "at https://tinyurl.com/y5f9pzx8 ",
+        help="With `data_submission` sub-command: string, path to html form. With "
+        "`process` sub-command: string, path to `.csv` file listing newly delivered "
+        "sequencing data from the genome center. OR, list of comma separated sample "
+        "names (no spaces)- override the `.csv` file. A special case for `process` "
+        "sub-command: pass `-`, and follow the prompt on screen. For more details "
+        "and examples follow the documentation at https://tinyurl.com/y5f9pzx8 ",
     )
 
     ggroup.add_argument(
@@ -226,6 +226,22 @@ def parse_arguments(argsv: str = None) -> argparse.Namespace:
         help="Skip copying files to AWS.",
     )
 
+    process_parser.add_argument(
+        "--source_path",
+        dest="source_path",
+        action="store",
+        nargs="?",
+        help="Source directory of samples listed with `--file`.",
+    )
+
+    process_parser.add_argument(
+        "--target_path",
+        dest="target_path",
+        action="store",
+        nargs="?",
+        help="Copying target directory for samples listed with `--file`.",
+    )
+
     process_parser.add_argument(
         "--seqc-args",
         dest="seqcargs",
