@@ -15,6 +15,7 @@ from collections import ChainMap, namedtuple
 from typing import Dict, Iterable, List, Optional, Tuple, Union
 
 import boto3
+import mysql
 import numpy as np
 import pandas as pd
 import yaml
@@ -520,27 +521,31 @@ def sample_data_frame(sd: pd.DataFrame) -> pd.DataFrame:
             )
             logging.warning(msg)
 
-    table_dict = {"HTO": "hashtag_lib", "TCR": "TCR_lib", None: "sample_data"}
-    sample_data["label"] = sample_data["label"].map(table_dict)
+    if not sample_data.empty:
+        table_dict = {"HTO": "hashtag_lib", "TCR": "TCR_lib", None: "sample_data"}
+        sample_data["label"] = sample_data["label"].map(table_dict)
 
-    sample_data["source"] = (
-        sample_data["project_loc"].str.cat(sample_data["old_basename"], sep="/") + "/"
-    )
-    sample_data["s3uri"] = (
-        sample_data["s3_loc"].str.cat(sample_data["sample"], sep="/") + "/"
-    )
-    sample_data["igo_id"] = sample_data.project_loc.str.lstrip(
-        "/Volumes/peerd/FASTQ/Project_"
-    )
-    sample_data["igo_id"] = sample_data.igo_id.str.split(pat="/", n=1, expand=True)[0]
+        sample_data["source"] = (
+            sample_data["project_loc"].str.cat(sample_data["old_basename"], sep="/")
+            + "/"
+        )
+        sample_data["s3uri"] = (
+            sample_data["s3_loc"].str.cat(sample_data["sample"], sep="/") + "/"
+        )
+        sample_data["igo_id"] = "NULL"
+        for pl in sample_data.itertuples():
+            if pl.project_loc.startswith("/Volumes/peerd/FASTQ/Project_"):
+                igo_id = pl.project_loc.lstrip("/Volumes/peerd/FASTQ/Project_")
+                igo_id = igo_id.split("/")[0]
+                sample_data.loc[sample_data.id == pl.id, "igo_id"] = igo_id
 
-    sample_data["platform"] = "NULL"
-    sample_data["platform"] = sample_data["run_name"].map(di)
+        sample_data["platform"] = "NULL"
+        sample_data["platform"] = sample_data["run_name"].map(di)
 
     return sample_data
 
 
-def prepare_statements(sample_data: pd.DataFrame) -> dict:
+def prepare_statements(sample_data: pd.DataFrame) -> Tuple[Dict, List]:
     """\
     A constructor for `aws s3 cp` command and MySQL statements.
 
@@ -551,15 +556,36 @@ def prepare_statements(sample_data: pd.DataFrame) -> dict:
         A set of aws copy commands, and MySQL update commands
     """
     sample_set = {}
+    failed = []
     for sample_ in sample_data.itertuples():
         cmd = []
         root_source = os.path.join(sample_.project_loc, sample_.old_basename, "")
         data_storage = os.path.join(sample_.s3_loc, sample_.sample, "")
 
+        if sample_.label != "sample_data":
+            whereid = "sampleData_id"
+        else:
+            whereid = "id"
+        if sample_.label == "hashtag_lib":
+            h_status = ", `status`=2"
+        else:
+            h_status = ""
+        statement = (
+            "UPDATE {} SET AWS_storage='{}', source_path='{}'{} WHERE {}="
+            "{}".format(
+                sample_.label, data_storage, root_source, h_status, whereid, sample_.id
+            )
+        )
+
         if root_source.startswith("s3://"):
             list_files = get_bucket_contents(root_source)
         else:
-            list_files = os.listdir(root_source)
+            try:
+                list_files = os.listdir(root_source)
+            except FileNotFoundError as e:
+                logging.error(str(e))
+                failed.append(sample_.id)
+                continue
 
         for file in list_files:
             if sample_.run_name in [
@@ -601,9 +627,11 @@ def prepare_statements(sample_data: pd.DataFrame) -> dict:
                     _, bucket, key, _, _ = urllib.parse.urlsplit(target_genomic)
                     cmd.append([bucket, key.strip("/"), source_genomic])
 
-        sample_set[str(sample_.id) + "_" + sample_.label] = dict(cmd=cmd)
+        sample_set[str(sample_.id) + "_" + sample_.label] = dict(
+            cmd=cmd, statement=statement
+        )
 
-    return sample_set
+    return sample_set, failed
 
 
 def put_object(
@@ -718,7 +746,9 @@ def copy_files_to_processing_folder(sample_data: pd.DataFrame, **kwargs) -> List
     """
     failed_samples = []
     # copy fastq files, rename the samples, and update the database
-    sample_set = prepare_statements(sample_data)
+    sample_set, failed = prepare_statements(sample_data)
+    if failed:
+        failed_samples.extend(failed)
     for key in sample_set:
 
         # before any copying to S3 assert IGO dates are are not missing
@@ -748,13 +778,34 @@ def copy_files_to_processing_folder(sample_data: pd.DataFrame, **kwargs) -> List
             logging.warning("Fix the missing dates and try again..")
             failed_samples.append(str(key.split("_")[0]))
         else:
+            success_list = []
             for cmd in sample_set[key]["cmd"]:
                 dest_bucket_name, dest_object_name, src_data = cmd
                 msg, success = put_object(
                     dest_bucket_name, dest_object_name, src_data, kwargs["md5sums"],
                 )
-                if not success:
-                    failed_samples.append(str(key))
+
+                try:
+                    assert isinstance(success, bool), " ".join(
+                        [msg.decode(), success, src_data]
+                    )
+                except AssertionError as e:
+                    print(str(e))
+                    success_list.append(False)
+                else:
+                    success_list.append(success)
+
+            try:
+                assert all(success_list)
+                # update the database
+                db_connect.cur.execute(sample_set[key]["statement"])
+                print(db_connect.cur.statement)
+            except (AssertionError, mysql.connector.Error) as err:
+                failed_samples.append(str(key))
+                logging.error(err)
+                db_connect.db.rollback()
+            finally:
+                db_connect.db.commit()
 
     return failed_samples
 
