@@ -93,8 +93,6 @@ def worker_main(
     print("Processing new fastq files ...")
 
     # read in delivery report
-    if isinstance(f_in, list):
-        f_in = " ".join(f_in)
     if os.path.isfile(f_in):
         sd = pd.read_csv(f_in, index_col=0)
     elif f_in == "-":
@@ -160,6 +158,11 @@ def worker_main(
         print(tabulate(sd, headers="keys", tablefmt="fancy_grid", showindex=False))
 
     else:
+        if isinstance(f_in, list):
+            f_in = " ".join(f_in)
+        else:
+            f_in = re.sub(",", " ", f_in)
+
         if any([source_path is None, target_path is None]):
             print("WARNING: Missing at least one of source_path and target_path!")
             return
@@ -168,9 +171,20 @@ def worker_main(
         )
 
     sample_data = sample_data_frame(sd)
-    failed_samples = []
+
     if not no_rsync:
         failed_samples = copy_files_to_processing_folder(sample_data, **args)
+        if failed_samples:
+            logging.warning(
+                "Samples {} will be excluded from processing due to failed upload or "
+                "other issues related to copy_files_to_processing_folder!".format(
+                    failed_samples
+                )
+            )
+            criterion = sample_data["id"].map(
+                lambda x: int(x) not in [int(i) for i in failed_samples]
+            )
+            sample_data = sample_data[criterion]
 
     # write the processing jobs to yaml
     # need to determine `run_name` to build proper yaml files
@@ -181,10 +195,7 @@ def worker_main(
             "Samples {} will be excluded from processing due to missing "
             "meta data!".format(sample_data.id[exclude_index].tolist())
         )
-    sample_data = sample_data.iloc[filter_index]
-
-    criterion = sample_data["id"].map(lambda x: str(x) not in failed_samples)
-    sample_data_ = sample_data[criterion]
+    sample_data_ = sample_data.iloc[filter_index].copy()
 
     if sample_data_.empty:
         print("\nSample data frame is empty! Nothing to process!...\n")
@@ -199,19 +210,19 @@ def worker_main(
         "VALUES (%s,%s,%s,%s,%s)"
     )
     q_raw = (
-        "SELECT * FROM `raw_data` WHERE `sampleData_id`={} "
-        "AND `platform`={} AND `IGO_id`={}"
+        "SELECT * FROM `raw_data` WHERE `sampleData_id`=%s "
+        "AND `platform`=%s AND `IGO_id`=%s"
     )
     q_records = (
         "INSERT INTO `run_records` (`rawData_id`,`tools_id`,`workflow_id`, `state`) "
         "VALUES (%s,%s,%s,1)"
     )
-    q_tool = "SELECT `id` FROM `tools` WHERE `tool`='{}'"
+    q_tool = "SELECT `id` FROM `tools` WHERE `tool`=%s"
 
     # record raw data in the database
     for row in sample_data_.itertuples():
         # query the table to prevent duplicate entries
-        db_connect.cur.execute(q_raw.format(row.id, row.platform, row.igo_id))
+        db_connect.cur.execute(q_raw, (row.id, row.platform, row.igo_id,))
         res = [i for i in db_connect.cur.fetchall()]
         if not res:
             db_connect.cur.execute(
@@ -242,7 +253,7 @@ def worker_main(
     if idx_seqc.any():
         config_jobs_yml = os.path.join(args["dockerizedSEQC"], "config", args["jobs"])
         db_connect.cur.execute(
-            q_tool.format(os.path.basename(args["dockerizedSEQC"].rstrip("/")))
+            q_tool, (os.path.basename(args["dockerizedSEQC"].rstrip("/")),)
         )
         try:
             tools_id = [i[0] for i in db_connect.cur.fetchall()][0]
@@ -266,7 +277,7 @@ def worker_main(
                 idx_seqc, ["id", "platform", "igo_id", "source", "s3uri"]
             ].itertuples():
 
-                db_connect.cur.execute(q_raw.format(row.id, row.platform, row.igo_id))
+                db_connect.cur.execute(q_raw, (row.id, row.platform, row.igo_id,))
                 rawData_id = [i[0] for i in db_connect.cur.fetchall()]
 
                 if rawData_id:
@@ -283,7 +294,7 @@ def worker_main(
             atac_path = os.path.expanduser(atac_path)
         else:
             atac_path = args["tool_path"]
-        db_connect.cur.execute(q_tool.format(os.path.basename(atac_path.rstrip("/"))))
+        db_connect.cur.execute(q_tool, (os.path.basename(atac_path.rstrip("/")),))
         try:
             tools_id = [i[0] for i in db_connect.cur.fetchall()][0]
         except IndexError:
@@ -304,7 +315,7 @@ def worker_main(
                 idx_atac, ["id", "platform", "igo_id", "source", "s3uri"]
             ].itertuples():
 
-                db_connect.cur.execute(q_raw.format(row.id, row.platform, row.igo_id))
+                db_connect.cur.execute(q_raw, (row.id, row.platform, row.igo_id,))
                 rawData_id = [i[0] for i in db_connect.cur.fetchall()]
 
                 if rawData_id:
@@ -324,7 +335,7 @@ def worker_main(
         else:
             feature_barcoding_path = args["tool_path"]
         db_connect.cur.execute(
-            q_tool.format(os.path.basename(feature_barcoding_path.rstrip("/")))
+            q_tool, (os.path.basename(feature_barcoding_path.rstrip("/")),)
         )
         try:
             tools_id = [i[0] for i in db_connect.cur.fetchall()][0]
@@ -388,7 +399,7 @@ def worker_main(
                         "igo_id",
                     ].values[0]
 
-                    db_connect.cur.execute(q_raw.format(label_id, platform, igo_id))
+                    db_connect.cur.execute(q_raw, (label_id, platform, igo_id,))
                     rawData_id = [i[0] for i in db_connect.cur.fetchall()]
                     db_connect.cur.execute(
                         q_records,
@@ -418,7 +429,7 @@ def worker_main(
             vdj_path = os.path.expanduser(vdj_path)
         else:
             vdj_path = args["tool_path"]
-        db_connect.cur.execute(q_tool.format(os.path.basename(vdj_path.rstrip("/"))))
+        db_connect.cur.execute(q_tool, (os.path.basename(vdj_path.rstrip("/")),))
         try:
             tools_id = [i[0] for i in db_connect.cur.fetchall()][0]
         except IndexError:
@@ -470,7 +481,7 @@ def worker_main(
                         "igo_id",
                     ].values[0]
 
-                    db_connect.cur.execute(q_raw.format(label_id, platform, igo_id))
+                    db_connect.cur.execute(q_raw, (label_id, platform, igo_id,))
                     rawData_id = [i[0] for i in db_connect.cur.fetchall()]
                     db_connect.cur.execute(
                         q_records,
@@ -500,9 +511,7 @@ def worker_main(
             cellranger_path = os.path.expanduser(cellranger_path)
         else:
             cellranger_path = args["tool_path"]
-        db_connect.cur.execute(
-            q_tool.format(os.path.basename(cellranger_path.rstrip("/")))
-        )
+        db_connect.cur.execute(q_tool, (os.path.basename(cellranger_path.rstrip("/")),))
         try:
             tools_id = [i[0] for i in db_connect.cur.fetchall()][0]
         except IndexError:
@@ -523,7 +532,7 @@ def worker_main(
                 idx_cellranger, ["id", "platform", "igo_id", "source", "s3uri"]
             ].itertuples():
 
-                db_connect.cur.execute(q_raw.format(row.id, row.platform, row.igo_id))
+                db_connect.cur.execute(q_raw, (row.id, row.platform, row.igo_id,))
                 rawData_id = [i[0] for i in db_connect.cur.fetchall()]
 
                 if rawData_id:
